tab_perutimber_position: List of the number positions of the first 3 letters of the species name in
the tab_perutimber
Description
The 'tab_perutimber_position' reports the
position (in term of number of rows) of the first three letters (triphthong)
for the plant names stored in the variable 'accepted_name' of the table
'tab_perutimber'. This indexing system speeds up of the search on the
largest list using the package.
Usage
tab_perutimber_position
Arguments
Format
A data frame with 399 observations on the following 3 variables.
position
A character vector. It is the position of
the first 3 letters of the species name in the tab_perutimber.
triphthong
A character vector. First 3 letters of the species
name in the tab_perutimber.